==> paraview-5.12.1-8-x86_64.pkg.tar.zst: opt/paraview/lib/cmake/paraview/Prism-targets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Prism::vtkPrismFilters" for configuration "Release"
set_property(TARGET Prism::vtkPrismFilters APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Prism::vtkPrismFilters PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "VTK::CommonCore;VTK::CommonDataModel;VTK::FiltersCore;VTK::FiltersGeneral;VTK::fmt"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/paraview/plugins/Prism/libvtkPrismFilters.so"
  IMPORTED_SONAME_RELEASE "libvtkPrismFilters.so"
  )

list(APPEND _cmake_import_check_targets Prism::vtkPrismFilters )
list(APPEND _cmake_import_check_files_for_Prism::vtkPrismFilters "${_IMPORT_PREFIX}/lib/paraview/plugins/Prism/libvtkPrismFilters.so" )

# Import target "Prism::vtkPrismViews" for configuration "Release"
set_property(TARGET Prism::vtkPrismViews APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Prism::vtkPrismViews PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "ParaView::RemotingCore;Prism::vtkPrismFilters;VTK::CommonCore;VTK::CommonDataModel;VTK::FiltersExtraction;VTK::FiltersGeometry"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/paraview/plugins/Prism/libvtkPrismViews.so"
  IMPORTED_SONAME_RELEASE "libvtkPrismViews.so"
  )

list(APPEND _cmake_import_check_targets Prism::vtkPrismViews )
list(APPEND _cmake_import_check_files_for_Prism::vtkPrismViews "${_IMPORT_PREFIX}/lib/paraview/plugins/Prism/libvtkPrismViews.so" )

# Import target "Prism::vtkPrismServerManager" for configuration "Release"
set_property(TARGET Prism::vtkPrismServerManager APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Prism::vtkPrismServerManager PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "ParaView::RemotingCore;VTK::CommonCore;VTK::CommonDataModel"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/paraview/plugins/Prism/libvtkPrismServerManager.so"
  IMPORTED_SONAME_RELEASE "libvtkPrismServerManager.so"
  )

list(APPEND _cmake_import_check_targets Prism::vtkPrismServerManager )
list(APPEND _cmake_import_check_files_for_Prism::vtkPrismServerManager "${_IMPORT_PREFIX}/lib/paraview/plugins/Prism/libvtkPrismServerManager.so" )

# Import target "Prism::vtkPrismReaders" for configuration "Release"
set_property(TARGET Prism::vtkPrismReaders APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Prism::vtkPrismReaders PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "VTK::CommonCore;VTK::CommonDataModel;VTK::CommonMisc;VTK::FiltersGeometry"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/paraview/plugins/Prism/libvtkPrismReaders.so"
  IMPORTED_SONAME_RELEASE "libvtkPrismReaders.so"
  )

list(APPEND _cmake_import_check_targets Prism::vtkPrismReaders )
list(APPEND _cmake_import_check_files_for_Prism::vtkPrismReaders "${_IMPORT_PREFIX}/lib/paraview/plugins/Prism/libvtkPrismReaders.so" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> paraview-5.13.1-7-x86_64.pkg.tar.zst: opt/paraview/lib/cmake/paraview/Prism-targets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Prism::vtkPrismFilters" for configuration "Release"
set_property(TARGET Prism::vtkPrismFilters APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Prism::vtkPrismFilters PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "VTK::CommonCore;VTK::CommonDataModel;VTK::FiltersCore;VTK::FiltersGeneral"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/paraview/plugins/Prism/libvtkPrismFilters.so"
  IMPORTED_SONAME_RELEASE "libvtkPrismFilters.so"
  )

list(APPEND _cmake_import_check_targets Prism::vtkPrismFilters )
list(APPEND _cmake_import_check_files_for_Prism::vtkPrismFilters "${_IMPORT_PREFIX}/lib/paraview/plugins/Prism/libvtkPrismFilters.so" )

# Import target "Prism::vtkPrismViews" for configuration "Release"
set_property(TARGET Prism::vtkPrismViews APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Prism::vtkPrismViews PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "ParaView::RemotingCore;Prism::vtkPrismFilters;VTK::CommonCore;VTK::CommonDataModel;VTK::FiltersExtraction;VTK::FiltersGeometry"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/paraview/plugins/Prism/libvtkPrismViews.so"
  IMPORTED_SONAME_RELEASE "libvtkPrismViews.so"
  )

list(APPEND _cmake_import_check_targets Prism::vtkPrismViews )
list(APPEND _cmake_import_check_files_for_Prism::vtkPrismViews "${_IMPORT_PREFIX}/lib/paraview/plugins/Prism/libvtkPrismViews.so" )

# Import target "Prism::vtkPrismServerManager" for configuration "Release"
set_property(TARGET Prism::vtkPrismServerManager APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Prism::vtkPrismServerManager PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "ParaView::RemotingCore;VTK::CommonCore;VTK::CommonDataModel"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/paraview/plugins/Prism/libvtkPrismServerManager.so"
  IMPORTED_SONAME_RELEASE "libvtkPrismServerManager.so"
  )

list(APPEND _cmake_import_check_targets Prism::vtkPrismServerManager )
list(APPEND _cmake_import_check_files_for_Prism::vtkPrismServerManager "${_IMPORT_PREFIX}/lib/paraview/plugins/Prism/libvtkPrismServerManager.so" )

# Import target "Prism::vtkPrismReaders" for configuration "Release"
set_property(TARGET Prism::vtkPrismReaders APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Prism::vtkPrismReaders PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "VTK::CommonCore;VTK::CommonDataModel;VTK::CommonMisc;VTK::FiltersGeometry"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/paraview/plugins/Prism/libvtkPrismReaders.so"
  IMPORTED_SONAME_RELEASE "libvtkPrismReaders.so"
  )

list(APPEND _cmake_import_check_targets Prism::vtkPrismReaders )
list(APPEND _cmake_import_check_files_for_Prism::vtkPrismReaders "${_IMPORT_PREFIX}/lib/paraview/plugins/Prism/libvtkPrismReaders.so" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
